Coverage for vcr.errors: 100%

# Coverage for vcr.errors : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 | class CannotOverwriteExistingCassetteException(Exception): pass class UnhandledHTTPRequestError(KeyError): ''' Raised when a cassette does not c ontain the request we want ''' pass